@@ -6,7 +6,7 @@
 /*  which you can customize.                                   */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -154,12 +154,6 @@
 #define PSBEGIN2 "# rem2ps2 begin"
 #define PSEND2   "# rem2ps2 end"
 
-#if defined(HAVE_MBSTOWCS) && defined(HAVE_WCTYPE_H)
-#define REM_USE_WCHAR 1
-#else
-#undef REM_USE_WCHAR
-#endif
-
 #if defined(HAVE_READLINE) && defined(HAVE_READLINE_READLINE_H)
 #define USE_READLINE 1
 #else
