@@ -5,7 +5,7 @@
 /*  Code to suppress duplicate reminders                       */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -101,7 +101,7 @@ InsertDedupeEntry(int trigger_date, int trigger_time, char const *body)
     }
     e->trigger_date = trigger_date;
     e->trigger_time = trigger_time;
-    e->body = StrDup(body);
+    e->body = strdup(body);
     if (!e->body) {
         free(e);
         return;
