@@ -5,7 +5,7 @@
 /*  Function Prototypes.                                       */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -13,20 +13,8 @@
 /* Suppress unused variable warnings */
 #define UNUSED(x) (void) x
 
-#ifdef HAVE_STRDUP
-#define StrDup strdup
-#endif
-
-#ifdef HAVE_STRNCASECMP
-#define StrinCmp strncasecmp
-#endif
-
-#ifdef HAVE_STRCASECMP
-#define StrCmpi strcasecmp
-#endif
-
 /* Define a string assignment macro - be careful!!! */
-#define STRSET(x, str) { if (x) free(x); (x) = StrDup(str); }
+#define STRSET(x, str) { if (x) free(x); (x) = strdup(str); }
 
 /* Define a general malloc routine for creating pointers to objects */
 #define NEW(type) (malloc(sizeof(type)))
@@ -131,18 +119,6 @@ int ComputeTriggerNoAdjustDuration (int today, Trigger *trig, TimeTrig const *ti
 int AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int save_in_globals);
 char *StrnCpy (char *dest, char const *source, int n);
 
-#ifndef HAVE_STRNCASECMP
-int StrinCmp (char const *s1, char const *s2, int n);
-#endif
-
-#ifndef HAVE_STRDUP
-char *StrDup (char const *s);
-#endif
-
-#ifndef HAVE_STRCASECMP
-int StrCmpi (char const *s1, char const *s2);
-#endif
-
 void strtolower(char *s);
 
 Var *FindVar (char const *str, int create);
@@ -168,13 +144,14 @@ int ParseNonSpaceChar (ParsePtr p, int *err, int peek);
 unsigned int HashVal_preservecase(char const *str);
 int DateOK (int y, int m, int d);
 BuiltinFunc *FindBuiltinFunc (char const *name);
-int InsertIntoSortBuffer (int dse, int tim, char const *body, int typ, int prio);
+int InsertIntoSortBuffer (int dse, int tim, char const *url, char const *body, int typ, int prio);
 void IssueSortedReminders (void);
 UserFunc *FindUserFunc(char const *name);
 int UserFuncExists (char const *fn);
 void DSEToHeb (int dse, int *hy, int *hm, int *hd);
 int HebNameToNum (char const *mname);
 char const *HebMonthName (int m, int y);
+char const *IvritMonthName (int m, int y);
 int HebToDSE (int hy, int hm, int hd);
 int GetValidHebDate (int yin, int min, int din, int adarbehave, int *mout, int *dout, int yahr);
 int GetNextHebrewDate (int dsestart, int hm, int hd, int yahr, int adarbehave, int *ans);
@@ -183,7 +160,7 @@ int GetSysVar (char const *name, Value *val);
 int SetSysVar (char const *name, Value *val);
 void DumpSysVarByName (char const *name);
 int CalcMinsFromUTC (int dse, int tim, int *mins, int *isdst);
-void FillParagraph (char const *s, DynamicBuffer *output);
+void FillParagraph (char const *url, char const *s, DynamicBuffer *output);
 void LocalToUTC (int locdate, int loctime, int *utcdate, int *utctime);
 void UTCToLocal (int utcdate, int utctime, int *locdate, int *loctime);
 int MoonPhase (int date, int time);
@@ -224,12 +201,10 @@ void FixSpecialType(Trigger *trig);
 void WriteJSONTrigger(Trigger const *t, int include_tags);
 void WriteJSONTimeTrigger(TimeTrig const *tt);
 int GetOnceDate(void);
-#ifdef REM_USE_WCHAR
 #define _XOPEN_SOURCE 600
 #include <wctype.h>
 #include <wchar.h>
 void PutWideChar(wchar_t const wc, DynamicBuffer *output);
-#endif
 
 /* These functions are in utils.c and are used to detect overflow
    in various arithmetic operators.  They have to be in separate
