@@ -5,7 +5,7 @@
 /*  Queue up reminders for subsequent execution.               */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2025 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2026 by Dianne Skoll                    */
 /*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
@@ -140,7 +140,7 @@ int QueueReminder(ParsePtr p, Trigger *trig,
                   TimeTrig const *tim, char const *sched)
 {
     QueuedRem *qelem;
-
+    TrigInfo *ti;
     if (DontQueue ||
         trig->noqueue ||
         tim->ttime == NO_TIME ||
@@ -155,7 +155,7 @@ int QueueReminder(ParsePtr p, Trigger *trig,
     qelem->red = DefaultColorR;
     qelem->green = DefaultColorG;
     qelem->blue = DefaultColorB;
-    qelem->text = StrDup(p->pos);  /* Guaranteed that parser is not nested. */
+    qelem->text = strdup(p->pos);  /* Guaranteed that parser is not nested. */
     if (!qelem->text) {
         free(qelem);
         return E_NO_MEM;
@@ -169,8 +169,13 @@ int QueueReminder(ParsePtr p, Trigger *trig,
     qelem->tt = *tim;
     qelem->t = *trig;
 
-    /* Take over infos */
-    trig->infos = NULL;
+    /* Copy infos */
+    qelem->t.infos = NULL;
+    ti = trig->infos;
+    while(ti) {
+        (void) AppendTrigInfo(&qelem->t, ti->info);
+        ti = ti->next;
+    }
 
     DBufInit(&(qelem->t.tags));
     DBufPuts(&(qelem->t.tags), DBufValue(&(trig->tags)));
