@@ -985,6 +985,14 @@ static void Init(int argc, char const *argv[])
 
         case 'e': FillPage = 1; break;
 
+        case '-':
+            if (!strcmp(s, "version")) {
+                printf("rem2ps version %s\n", VERSION);
+                exit(0);
+            }
+            Usage("Unrecognized option");
+            break;
+
         default: Usage("Unrecognized option");
         }
     }
@@ -1016,6 +1024,7 @@ void Usage(char const *s)
     fprintf(stderr, "-e            Make calendar fill entire page\n");
     fprintf(stderr, "-x            Put day numbers on left instead of right\n");
     fprintf(stderr, "-o[lrtb] marg Specify left, right, top and bottom margins\n");
+    fprintf(stderr, "--version     Print the version of rem2ps and exit\n");
     exit(EXIT_FAILURE);
 }
 
